@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import os
 import unittest
 from nose.plugins.xunit import Xunit
@@ -30,7 +31,24 @@ class TestXUnitPlugin(PluginTester, unittest.TestCase):
         print result
         
         assert '<?xml version="1.0" encoding="UTF-8"?>' in result
-        assert '<testsuite name="nosetests" tests="5" errors="1" failures="1" skip="1">' in result
-        assert '<testcase classname="test_xunit_as_suite.TestForXunit" name="test_xunit_as_suite.TestForXunit.test_error" time="0">' in result
+        assert '<testsuite name="nosetests" tests="6" errors="2" failures="1" skip="1">' in result
+        assert '<testcase classname="test_xunit_as_suite.TestForXunit" name="test_error" time="0">' in result
+        assert '<error type="exceptions.Exception" message="日本">' in result
         assert '</testcase>' in result
-        assert '</testsuite>' in result
\ No newline at end of file
+        assert '</testsuite>' in result
+
+
+class TestIssue279(PluginTester, unittest.TestCase):
+    activate = '--with-xunit'
+    args = ['-v','--xunit-file=%s' % xml_results_filename]
+    plugins = [Xunit(), Skip()]
+    suitepath = os.path.join(support, 'issue279')
+
+    def runTest(self):
+        print str(self.output)
+        f = open(xml_results_filename,'r')
+        result = f.read()
+        f.close()
+        print result
+        assert 'tests="1" errors="1" failures="0" skip="0"' in result
+        assert "Exception: I would prefer not to" in result
