@@ -5,8 +5,8 @@ from warnings import warn
 from nose.util import tolist
 
 class Plugin(object):
-    """Base class for nose plugins. It's not *necessary* to subclass this
-    class to create a plugin; however, all plugins must implement
+    """Base class for nose plugins. It's recommended but not *necessary* to
+    subclass this class to create a plugin, but all plugins *must* implement
     `options(self, parser, env)` and `configure(self, options, conf)`, and
     must have the attributes `enabled`, `name` and `score`.  The `name`
     attribute may contain hyphens ('-').
@@ -17,12 +17,12 @@ class Plugin(object):
     __init__, configure, and options, if you override them) will give
     your plugin some friendly default behavior:
 
-      * A --with-$name option will be added to the command line interface
-        to enable the plugin, and a corresponding environment variable
-        will be used as the default value. The plugin class's docstring
-        will be used as the help for this option.
-      * The plugin will not be enabled unless this option is selected by
-        the user.
+    * A --with-$name option will be added to the command line interface
+      to enable the plugin, and a corresponding environment variable
+      will be used as the default value. The plugin class's docstring
+      will be used as the help for this option.
+    * The plugin will not be enabled unless this option is selected by
+      the user.
     """
     can_configure = False
     enabled = False
@@ -35,19 +35,35 @@ class Plugin(object):
             self.name = self.__class__.__name__.lower()
         if self.enableOpt is None:
             self.enableOpt = "enable_plugin_%s" % self.name.replace('-', '_')
-            
-    def addOptions(self, parser, env=os.environ):
+
+    def addOptions(self, parser, env=None):
         """Add command-line options for this plugin.
 
         The base plugin class adds --with-$name by default, used to enable the
         plugin.
+
+        .. warning :: Don't implement addOptions unless you want to override
+                      all default option handling behavior, including
+                      warnings for conflicting options. Implement
+                      :meth:`options
+                      <nose.plugins.base.IPluginInterface.options>`
+                      instead.
         """
         self.add_options(parser, env)
-        
-    def add_options(self, parser, env=os.environ):
+
+    def add_options(self, parser, env=None):
         """Non-camel-case version of func name for backwards compatibility.
+
+        .. warning ::
+
+           DEPRECATED: Do not use this method,
+           use :meth:`options <nose.plugins.base.IPluginInterface.options>`
+           instead.
+
         """
-        # FIXME raise deprecation warning if wasn't called by wrapper 
+        # FIXME raise deprecation warning if wasn't called by wrapper
+        if env is None:
+            env = os.environ
         try:
             self.options(parser, env)
             self.can_configure = True
@@ -56,11 +72,13 @@ class Plugin(object):
                  "be disabled" % (self, e), RuntimeWarning)
             self.enabled = False
             self.can_configure = False
-            
-    def options(self, parser, env=os.environ):
-        """New plugin API: override to just set options. Implement
-        this method instead of addOptions or add_options for normal
-        options behavior with protection from OptionConflictErrors.
+
+    def options(self, parser, env):
+        """Register commandline options.
+
+        Implement this method for normal options behavior with protection from
+        OptionConflictErrors. If you override this method and want the default
+        --with-$name option to be registered, be sure to call super().
         """
         env_opt = 'NOSE_WITH_%s' % self.name.upper()
         env_opt = env_opt.replace('-', '_')
@@ -101,131 +119,21 @@ class Plugin(object):
 
 class IPluginInterface(object):
     """
-    Nose plugin API
-    ---------------
-
-    While it is recommended that plugins subclass
-    nose.plugins.Plugin, the only requirements for a plugin are
-    that it implement the methods `options(self, parser, env)` and
-    `configure(self, options, conf)`, and have the attributes
-    `enabled`, `name` and `score`.
-    
-    Plugins may implement any or all of the methods documented
-    below. Please note that they *must not* subclass `IPluginInterface`;
-    `IPluginInterface` is a only description of the plugin API.
-
-    When plugins are called, the first plugin that implements a method
-    and returns a non-None value wins, and plugin processing ends. The
-    exceptions to this are methods marked as `generative` or
-    `chainable`.  `generative` methods combine the output of all
-    plugins that respond with an iterable into a single flattened
-    iterable response (a generator, really). `chainable` methods pass
-    the results of calling plugin A as the input to plugin B, where
-    the positions in the chain are determined by the plugin sort
-    order, which is in order by `score` descending.
-
-    In general, plugin methods correspond directly to methods of
-    `nose.selector.Selector`, `nose.loader.TestLoader` and
-    `nose.result.TextTestResult` are called by those methods when they are
-    called. In some cases, the plugin hook doesn't neatly match the
-    method in which it is called; for those, the documentation for the
-    hook will tell you where in the test process it is called.
-
-    Plugin hooks fall into four broad categories: selecting and
-    loading tests, handling errors raised by tests, preparing objects
-    used in the testing process, and watching and reporting on test
-    results.
-    
-    Selecting and loading tests
-    ===========================
-
-    To alter test selection behavior, implement any necessary `want*`
-    methods as outlined below. Keep in mind, though, that when your
-    plugin returns True from a `want*` method, you will send the requested
-    object through the normal test collection process. If the object
-    represents something from which normal tests can't be collected, you
-    must also implement a loader method to load the tests.
-
-    Examples:
-    
-    * The builtin doctests plugin implements `wantFile` to enable
-      loading of doctests from files that are not python modules. It
-      also implements `loadTestsFromModule` to load doctests from
-      python modules, and `loadTestsFromFile` to load tests from the
-      non-module files selected by `wantFile`.
-       
-    * The builtin attrib plugin implements `wantFunction` and
-      `wantMethod` so that it can reject tests that don't match the
-      specified attributes.
-
-    Handling errors
-    ===============
-
-    To alter error handling behavior -- for instance to catch a
-    certain class of exception and handle it differently from the
-    normal error or failure handling -- you should subclass
-    `ErrorClassPlugin`. See the documentation for `ErrorClassPlugin`_ for
-    more details.
-
-    Examples:
-
-    * The builtin skip and deprecated plugins are ErrorClass plugins.
-
-    Preparing test objects
-    ======================
-
-    To alter, get a handle on, or replace test framework objects such
-    as the loader, result, runner, and test cases, use the appropriate
-    prepare methods. The simplest reason to use prepare is if you need
-    to use an object yourself. For example, the isolate plugin
-    implements `prepareTestLoader` so that it can use the test loader
-    later on to load tests. If you return a value from a prepare
-    method, that value will be used in place of the loader, result,
-    runner or test case, respectively. When replacing test cases, be
-    aware that you are replacing the entire test case -- including the
-    whole `run(result)` method of the `unittest.TestCase` -- so if you
-    want normal unittest test result reporting, you must implement the
-    same calls to result as `unittest.TestCase.run`.
-
-    Examples:
-
-    * The builtin isolate plugin implements `prepareTestLoader` but
-      does not replace the test loader.
-
-    * The builtin profile plugin implements `prepareTest` and does
-      replace the top-level test case by returning the case wrapped in
-      the profiler function.
-    
-    Watching or reporting on tests
-    ==============================
-
-    To record information about tests or other modules imported during
-    the testing process, output additional reports, or entirely change
-    test report output, implement any of the methods outlined below that
-    correspond to TextTestResult methods.
-
-    Examples:
-    
-    * The builtin cover plugin implements `begin` and `report` to
-      capture and report code coverage metrics for all or selected modules
-      loaded during testing.
-       
-    * The builtin profile plugin implements `begin`, `prepareTest` and
-      `report` to record and output profiling information. In this
-      case, the plugin's `prepareTest` method constructs a function that
-      runs the test through the hotshot profiler's runcall() method.     
+    IPluginInteface describes the plugin API. Do not subclass or use this
+    class directly.
     """
     def __new__(cls, *arg, **kw):
         raise TypeError("IPluginInterface class is for documentation only")
 
-    def addOptions(self, parser, env=os.environ):
-        """Called to allow plugin to register command line
-        options with the parser.
-
-        Do *not* return a value from this method unless you want to stop
+    def addOptions(self, parser, env):
+        """Called to allow plugin to register command-line options with the
+        parser. DO NOT return a value from this method unless you want to stop
         all other plugins from setting their options.
 
-        .. Note:: DEPRECATED -- implement `options` instead.
+        .. warning ::
+
+           DEPRECATED -- implement
+           :meth:`options <nose.plugins.base.IPluginInterface.options>` instead.
         """
         pass
     add_options = addOptions
@@ -236,11 +144,7 @@ class IPluginInterface(object):
         unless you want to stop other plugins from seeing the deprecated
         test.
 
-        .. Note:: DEPRECATED -- check error class in addError instead
-
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case 
+        .. warning :: DEPRECATED -- check error class in addError instead
         """
         pass
     addDeprecated.deprecated = True
@@ -250,15 +154,10 @@ class IPluginInterface(object):
         value unless you want to stop other plugins from seeing that the
         test has raised an error.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
-          capt : string
-            Captured output, if any
-            
-            .. Note:: DEPRECATED: this parameter will not be passed
+        :param test: the test case
+        :type test: :class:`nose.case.Test`            
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     addError.changed = True
@@ -267,19 +166,10 @@ class IPluginInterface(object):
         """Called when a test fails. DO NOT return a value unless you
         want to stop other plugins from seeing that the test has failed.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
-          capt : string
-            Captured output, if any.
-
-            .. Note:: DEPRECATED: this parameter will not be passed
-          tb_info : string
-            Introspected traceback info, if any
-           
-            .. Note:: DEPRECATED: this parameter will not be passed
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        :param err: 3-tuple
+        :type err: sys.exc_info() tuple
         """
         pass
     addFailure.changed = True
@@ -288,11 +178,7 @@ class IPluginInterface(object):
         """Called when a test is skipped. DO NOT return a value unless
         you want to stop other plugins from seeing the skipped test.
 
-        .. Note:: DEPRECATED -- check error class in addError instead
-
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
+        .. warning:: DEPRECATED -- check error class in addError instead
         """
         pass
     addSkip.deprecated = True
@@ -301,13 +187,8 @@ class IPluginInterface(object):
         """Called when a test passes. DO NOT return a value unless you
         want to stop other plugins from seeing the passing test.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          capt : string
-            Captured output, if any.
-
-            .. Note:: DEPRECATED: this parameter will not be passed            
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
         """
         pass
     addSuccess.changed = True
@@ -324,9 +205,8 @@ class IPluginInterface(object):
         """Called after all tests have been loaded from directory at path
         and run.
 
-        :Parameters:
-          path : string
-            the directory that has finished processing
+        :param path: the directory that has finished processing
+        :type path: string
         """
         pass
     afterDirectory._new = True
@@ -335,40 +215,37 @@ class IPluginInterface(object):
         """Called after module is imported from filename. afterImport
         is called even if the import failed.
 
-        :Parameters:
-          filename : string
-            The file that was loaded
-          module : string
-            The name of the module
+        :param filename: The file that was loaded
+        :type filename: string
+        :param filename: The name of the module
+        :type module: string
         """
         pass
-    afterImport._new = True        
+    afterImport._new = True
 
     def afterTest(self, test):
         """Called after the test has been run and the result recorded
         (after stopTest).
 
-        :Parameters:
-          test :  `nose.case.Test`_
-            the test case
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
         """
         pass
     afterTest._new = True
 
     def beforeContext(self):
         """Called before a context (generally a module) is
-        examined. Since the context is not yet loaded, plugins don't
+        examined. Because the context is not yet loaded, plugins don't
         get to know what the context is; so any context operations
         should use a stack that is pushed in `beforeContext` and popped
         in `afterContext` to ensure they operate symmetrically.
 
-        `beforeContext` and `afterContext` are mainly
-        useful for tracking and restoring global state around possible
-        changes from within a context, whatever the context may be. If
-        you need to operate on contexts themselves, see `startContext`
-        and `stopContext`, which are passed the context in question, but
-        are called after it has been loaded (imported in the module
-        case).
+        `beforeContext` and `afterContext` are mainly useful for tracking
+        and restoring global state around possible changes from within a
+        context, whatever the context may be. If you need to operate on
+        contexts themselves, see `startContext` and `stopContext`, which
+        are passed the context in question, but are called after
+        it has been loaded (imported in the module case).
         """
         pass
     beforeContext._new = True
@@ -376,9 +253,7 @@ class IPluginInterface(object):
     def beforeDirectory(self, path):
         """Called before tests are loaded from directory at path.
 
-        :Parameters:
-          path : string
-            the directory that is about to be processed
+        :param path: the directory that is about to be processed
         """
         pass
     beforeDirectory._new = True
@@ -386,24 +261,21 @@ class IPluginInterface(object):
     def beforeImport(self, filename, module):
         """Called before module is imported from filename.
 
-        :Parameters:
-          filename : string
-            The file that will be loaded
-          module : string
-            The name of the module found in file
+        :param filename: The file that will be loaded
+        :param module: The name of the module found in file
+        :type module: string
         """
     beforeImport._new = True
-    
+
     def beforeTest(self, test):
         """Called before the test is run (before startTest).
-        
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-        """        
+
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        """
         pass
     beforeTest._new = True
-            
+ 
     def begin(self):
         """Called before any tests are collected or run. Use this to
         perform any setup needed before testing begins.
@@ -416,7 +288,7 @@ class IPluginInterface(object):
         config storage or changes to state or operation that are set
         by command line options.
 
-        Do *not* return a value from this method unless you want to
+        DO NOT return a value from this method unless you want to
         stop all other plugins from being configured.
         """
         pass
@@ -425,23 +297,25 @@ class IPluginInterface(object):
         """Called after all report output, including output from all
         plugins, has been sent to the stream. Use this to print final
         test results or perform final cleanup. Return None to allow
-        other plugins to continue printing, any other value to stop
+        other plugins to continue printing, or any other value to stop
         them.
 
+        :param result: test result object
+        
         .. Note:: When tests are run under a test runner other than
-           `nose.core.TextTestRunner`_, for example when tests are run
+           :class:`nose.core.TextTestRunner`, such as
            via ``python setup.py test``, this method may be called
            **before** the default report output is sent.
         """
         pass
 
     def describeTest(self, test):
-        """Return a test description. Called by
-        `nose.case.Test.shortDescription`.
+        """Return a test description.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
+        Called by :meth:`nose.case.Test.shortDescription`.
+
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
         """
         pass
     describeTest._new = True
@@ -449,13 +323,12 @@ class IPluginInterface(object):
     def formatError(self, test, err):
         """Called in result.addError, before plugin.addError. If you
         want to replace or modify the error tuple, return a new error
-        tuple. 
+        tuple.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     formatError._new = True
@@ -466,16 +339,15 @@ class IPluginInterface(object):
     def formatFailure(self, test, err):
         """Called in result.addFailure, before plugin.addFailure. If you
         want to replace or modify the error tuple, return a new error
-        tuple. Since this method is chainable, you must return the
+        tuple. Because this method is chainable, you must return the
         test as well, so you you'll return something like::
 
           return (test, err)
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     formatFailure._new = True
@@ -487,11 +359,10 @@ class IPluginInterface(object):
         """Called on addError. To handle the error yourself and prevent normal
         error processing, return a true value.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     handleError._new = True
@@ -500,11 +371,10 @@ class IPluginInterface(object):
         """Called on addFailure. To handle the failure yourself and
         prevent normal failure processing, return a true value.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
-          err : 3-tuple
-            sys.exc_info() tuple
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     handleFailure._new = True
@@ -516,45 +386,46 @@ class IPluginInterface(object):
         Return None if your plugin cannot collect any tests from
         directory.
 
-        :Parameters:
-          path : string
-            The path to the directory.
+        :param  path: The path to the directory.
         """
         pass
     loadTestsFromDir.generative = True
     loadTestsFromDir._new = True
     
-    def loadTestsFromModule(self, module):
+    def loadTestsFromModule(self, module, path=None):
         """Return iterable of tests in a module. May be a
         generator. Each item returned must be a runnable
         unittest.TestCase (or subclass) instance.
         Return None if your plugin cannot
         collect any tests from module.
 
-        :Parameters:
-          module : python module 
-            The module object
+        :param module: The module object
+        :type module: python module
+        :param path: the path of the module to search, to distinguish from
+            namespace package modules
+
+            .. note::
+
+               NEW. The ``path`` parameter will only be passed by nose 0.11
+               or above.
         """
         pass
     loadTestsFromModule.generative = True
-    
+
     def loadTestsFromName(self, name, module=None, importPath=None):
         """Return tests in this file or module. Return None if you are not able
         to load any tests, or an iterable if you are. May be a
         generator.
 
-        :Parameters:
-          name : string
-            The test name. May be a file or module name plus a test
+        :param name: The test name. May be a file or module name plus a test
             callable. Use split_test_name to split into parts. Or it might
             be some crazy name of your own devising, in which case, do
             whatever you want.
-          module : python module
-            Module from which the name is to be loaded
-          importPath :
-            Path from which file (must be a python module) was found
-            
-            .. Note:: DEPRECATED: this argument will NOT be passed.
+        :param module: Module from which the name is to be loaded
+        :param importPath: Path from which file (must be a python module) was
+            found
+
+            .. warning:: DEPRECATED: this argument will NOT be passed.
         """
         pass
     loadTestsFromName.generative = True
@@ -565,11 +436,9 @@ class IPluginInterface(object):
         may implement loadTestsFromNames; the remaining name list from
         each will be passed to the next as input.
 
-        :Parameters:
-          names : iterable
-            List of test names.
-          module : python module
-            Module from which the names are to be loaded
+        :param names: List of test names.
+        :type names: iterable
+        :param module: Module from which the names are to be loaded
         """
         pass
     loadTestsFromNames._new = True
@@ -584,10 +453,8 @@ class IPluginInterface(object):
 
         .. Note:: This method replaces loadTestsFromPath from the 0.9
                   API.
-        
-        :Parameters:
-           filename : string
-             The full path to the file or directory.
+
+        :param filename: The full path to the file or directory.
         """
         pass
     loadTestsFromFile.generative = True
@@ -595,19 +462,18 @@ class IPluginInterface(object):
 
     def loadTestsFromPath(self, path):
         """
-        .. Note:: DEPRECATED -- use loadTestsFromFile instead
+        .. warning:: DEPRECATED -- use loadTestsFromFile instead
         """
         pass
     loadTestsFromPath.deprecated = True
-    
+
     def loadTestsFromTestCase(self, cls):
         """Return tests in this test case class. Return None if you are
         not able to load any tests, or an iterable if you are. May be a
         generator.
 
-        :Parameters:
-          cls : class
-            The test case class. Must be subclass of unittest.TestCase.
+        :param cls: The test case class. Must be subclass of
+           :class:`unittest.TestCase`.
         """
         pass
     loadTestsFromTestCase.generative = True
@@ -617,9 +483,8 @@ class IPluginInterface(object):
         unittest.TestCase subclass. Return None if you are not able to
         load any tests, an iterable if you are. May be a generator.
 
-        :Parameters:
-          cls : class
-            The test class. Must NOT be subclass of unittest.TestCase.
+        :param cls: The test case class. Must be **not** be subclass of
+           :class:`unittest.TestCase`.
         """
         pass
     loadTestsFromTestClass._new = True
@@ -632,22 +497,23 @@ class IPluginInterface(object):
         plugins to load an alternate test case or cases for an
         object. May be a generator.
 
-        :Parameters:
-          obj : any object
-            The object to be made into a test
-          parent : class, module or other object
-            The parent of obj (eg, for a method, the class)
-         """
+        :param obj: The object to be made into a test
+        :param parent: The parent of obj (eg, for a method, the class)
+        """
         pass
     makeTest._new = True
     makeTest.generative = True
 
-    def options(self, parser, env=os.environ):
+    def options(self, parser, env):
         """Called to allow plugin to register command line
         options with the parser.
 
-        Do *not* return a value from this method unless you want to stop
+        DO NOT return a value from this method unless you want to stop
         all other plugins from setting their options.
+
+        :param parser: options parser instance
+        :type parser: :class:`ConfigParser.ConfigParser`
+        :param env: environment, default is os.environ
         """
         pass
     options._new = True
@@ -663,9 +529,8 @@ class IPluginInterface(object):
         to modify or wrap individual test cases, use `prepareTestCase`
         instead.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
         """
         pass
 
@@ -682,9 +547,8 @@ class IPluginInterface(object):
         replacing the run() method of the test case -- including the
         exception handling and result calls, etc.
 
-        :Parameters:
-           test : `nose.case.Test`_
-             the test case
+        :param test: the test case
+        :type test: :class:`nose.case.Test`
         """
         pass
     prepareTestCase._new = True
@@ -695,9 +559,8 @@ class IPluginInterface(object):
         test loader, return None. Only one plugin may replace the test
         loader. Only valid when using nose.TestProgram.
 
-        :Parameters:
-           loader : `nose.loader.TestLoader` or other loader instance
-             the test loader
+        :param loader: :class:`nose.loader.TestLoader` 
+             (or other loader) instance
         """
         pass
     prepareTestLoader._new = True
@@ -716,9 +579,8 @@ class IPluginInterface(object):
         monkeypatch and stop other plugins from doing so, monkeypatch
         and return the patched result.
 
-        :Parameters:
-           result : `nose.result.TextTestResult` or other result instance
-             the test result
+        :param result: :class:`nose.result.TextTestResult` 
+             (or other result) instance
         """
         pass
     prepareTestResult._new = True
@@ -728,9 +590,8 @@ class IPluginInterface(object):
         return a test runner. To allow other plugins to process the
         test runner, return None. Only valid when using nose.TestProgram.
 
-        :Parameters:
-           runner : `nose.core.TextTestRunner` or other runner instance
-             the test runner
+        :param runner: :class:`nose.core.TextTestRunner` 
+             (or other runner) instance
         """
         pass
     prepareTestRunner._new = True
@@ -740,9 +601,8 @@ class IPluginInterface(object):
         plugin's report to the provided stream. Return None to allow
         other plugins to print reports, any other value to stop them.
 
-        :Parameters:
-           stream : file-like object
-             stream object; send your output here
+        :param stream: stream object; send your output here
+        :type stream: file-like object
         """
         pass
 
@@ -752,9 +612,8 @@ class IPluginInterface(object):
         `write(msg)` method. If you only want to note the stream, not
         capture or redirect it, then return None.
 
-        :Parameters:
-           stream : file-like object
-             the original output stream
+        :param stream: stream object; send your output here
+        :type stream: file-like object
         """
 
     def startContext(self, context):
@@ -762,10 +621,8 @@ class IPluginInterface(object):
         context. Note that tests have already been *loaded* from the
         context before this call.
 
-        :Parameters:
-           context : module, class or other object
-             the context about to be setup. May be a module or class, or any
-             other object that contains tests.
+        :param context: the context about to be setup. May be a module or
+             class, or any other object that contains tests.
         """
         pass
     startContext._new = True
@@ -774,9 +631,8 @@ class IPluginInterface(object):
         """Called before each test is run. DO NOT return a value unless
         you want to stop other plugins from seeing the test start.
 
-        :Parameters:
-           test : `nose.case.Test`_
-             the test case
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
 
@@ -784,9 +640,8 @@ class IPluginInterface(object):
         """Called after the tests in a context have run and the
         context has been torn down.
 
-        :Parameters:
-           context : module, class or other object
-             the context that has just been torn down.
+        :param context: the context about to be setup. May be a module or
+             class, or any other object that contains tests.
         """
         pass
     stopContext._new = True
@@ -795,18 +650,16 @@ class IPluginInterface(object):
         """Called after each test is run. DO NOT return a value unless
         you want to stop other plugins from seeing that the test has stopped.
 
-        :Parameters:
-          test : `nose.case.Test`_
-            the test case
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
 
     def testName(self, test):
         """Return a short test name. Called by `nose.case.Test.__str__`.
 
-        :Parameters:
-           test : `nose.case.Test`_
-             the test case
+        :param err: sys.exc_info() tuple
+        :type err: 3-tuple
         """
         pass
     testName._new = True
@@ -816,9 +669,7 @@ class IPluginInterface(object):
         tests from this class, false if you don't, and None if you don't
         care.
 
-        :Parameters:
-           cls : class
-             The class being examined by the selector
+        :param cls: The class being examined by the selector
         """
         pass
     
@@ -826,9 +677,7 @@ class IPluginInterface(object):
         """Return true if you want test collection to descend into this
         directory, false if you do not, and None if you don't care.
 
-        :Parameters:
-           dirname : string
-             Full path to directory being examined by the selector
+        :param dirname: Full path to directory being examined by the selector
         """
         pass
     
@@ -838,9 +687,7 @@ class IPluginInterface(object):
 
         Change from 0.9: The optional package parameter is no longer passed.
 
-        :Parameters:
-          file : string
-            Full path to file being examined by the selector
+        :param file: Full path to file being examined by the selector
         """
         pass
     
@@ -848,19 +695,16 @@ class IPluginInterface(object):
         """Return true to collect this function as a test, false to
         prevent it from being collected, and None if you don't care.
 
-        :Parameters:
-          function : function
-            The function object being examined by the selector
+        :param function: The function object being examined by the selector
         """
         pass
     
     def wantMethod(self, method):
         """Return true to collect this method as a test, false to
         prevent it from being collected, and None if you don't care.
-
-        :Parameters:
-          method : unbound method
-            The method object being examined by the selector
+        
+        :param method: The method object being examined by the selector
+        :type method: unbound method
         """    
         pass
     
@@ -869,16 +713,15 @@ class IPluginInterface(object):
         module, false to prevent the collector from descending into the
         module, and None if you don't care.
 
-        :Parameters:
-          module : python module
-            The module object being examined by the selector
+        :param module: The module object being examined by the selector
+        :type module: python module
         """
         pass
     
     def wantModuleTests(self, module):
         """
-        .. Note:: DEPRECATED -- this method will not be called, it has
-                  been folded into wantModule.
+        .. warning:: DEPRECATED -- this method will not be called, it has
+                     been folded into wantModule.
         """
         pass
     wantModuleTests.deprecated = True
