@@ -49,9 +49,20 @@ import logging
 import os
 import sys
 from warnings import warn
+import nose.config
 from nose.failure import Failure
 from nose.plugins.base import IPluginInterface
 
+try:
+    import cPickle as pickle
+except:
+    import pickle
+try:
+    from cStringIO import StringIO
+except:
+    from StringIO import StringIO
+
+
 __all__ = ['DefaultPluginManager', 'PluginManager', 'EntryPointPluginManager',
            'BuiltinPluginManager', 'RestrictedPluginManager']
 
@@ -77,10 +88,10 @@ class PluginProxy(object):
         self.plugins = []
         for p in plugins:
             self.addPlugin(p, call)
-    
+
     def __call__(self, *arg, **kw):
         return self.call(*arg, **kw)
-    
+
     def addPlugin(self, plugin, call):
         """Add plugin to my list of plugins to call, if it has the attribute
         I'm bound to.
@@ -108,8 +119,8 @@ class PluginProxy(object):
             return self.chain
         else:
             # return a value from the first plugin that returns non-None
-            return self.simple        
-            
+            return self.simple
+
     def chain(self, *arg, **kw):
         """Call plugins in a chain, where the result of each plugin call is
         sent to the next plugin as input. The final output result is returned.
@@ -171,7 +182,7 @@ class NoPlugins(object):
     """Null Plugin manager that has no plugins."""
     interface = IPluginInterface
     def __init__(self):
-        self.plugins = ()
+        self._plugins = self.plugins = ()
 
     def __iter__(self):
         return ()
@@ -216,7 +227,7 @@ class PluginManager(object):
     call.
     """
     proxyClass = PluginProxy
-    
+
     def __init__(self, plugins=(), proxyClass=None):
         self._plugins = []
         self._proxies = {}
@@ -224,7 +235,7 @@ class PluginManager(object):
             self.addPlugins(plugins)
         if proxyClass is not None:
             self.proxyClass = proxyClass
-        
+
     def __getattr__(self, call):
         try:
             return self._proxies[call]
@@ -237,6 +248,11 @@ class PluginManager(object):
         return iter(self.plugins)
 
     def addPlugin(self, plug):
+        # allow, for instance, plugins loaded via entry points to
+        # supplant builtin plugins.
+        new_name = getattr(plug, 'name', object())
+        self._plugins[:] = [p for p in self._plugins
+                            if getattr(p, 'name', None) != new_name]
         self._plugins.append(plug)
 
     def addPlugins(self, plugins):
@@ -286,7 +302,7 @@ class ZeroNinePlugin:
 
     def options(self, parser, env=os.environ):
         self.plugin.add_options(parser, env)
-    
+
     def addError(self, test, err):
         if not hasattr(self.plugin, 'addError'):
             return
@@ -300,7 +316,7 @@ class ZeroNinePlugin:
         elif issubclass(ec, DeprecatedTest):
             if not hasattr(self.plugin, 'addDeprecated'):
                 return
-            return self.plugin.addDeprecated(test.test)           
+            return self.plugin.addDeprecated(test.test)
         # add capt
         capt = test.capturedOutput
         return self.plugin.addError(test.test, err, capt)
@@ -336,14 +352,14 @@ class ZeroNinePlugin:
     def __getattr__(self, val):
         return getattr(self.plugin, val)
 
-            
+
 class EntryPointPluginManager(PluginManager):
     """Plugin manager that loads plugins from the `nose.plugins` and
     `nose.plugins.0.10` entry points.
     """
     entry_points = (('nose.plugins.0.10', None),
                     ('nose.plugins', ZeroNinePlugin))
-    
+
     def loadPlugins(self):
         """Load plugins by iterating the `nose.plugins` entry point.
         """
@@ -382,11 +398,11 @@ class BuiltinPluginManager(PluginManager):
     def loadPlugins(self):
         """Load plugins in nose.plugins.builtin
         """
-        super(BuiltinPluginManager, self).loadPlugins()
         from nose.plugins import builtin
         for plug in builtin.plugins:
             self.addPlugin(plug())
-        
+        super(BuiltinPluginManager, self).loadPlugins()
+
 try:
     import pkg_resources
     class DefaultPluginManager(BuiltinPluginManager, EntryPointPluginManager):
@@ -407,7 +423,7 @@ class RestrictedPluginManager(DefaultPluginManager):
         self.exclude = exclude
         self.excluded = []
         self._excludedOpts = None
-        
+
     def excludedOption(self, name):
         if self._excludedOpts is None:
             from optparse import OptionParser
@@ -415,7 +431,7 @@ class RestrictedPluginManager(DefaultPluginManager):
             for plugin in self.excluded:
                 plugin.options(self._excludedOpts, env={})
         return self._excludedOpts.get_option('--' + name)
-        
+
     def loadPlugins(self):
         if self.load:
             DefaultPluginManager.loadPlugins(self)
@@ -430,5 +446,3 @@ class RestrictedPluginManager(DefaultPluginManager):
             if ok:
                 allow.append(plugin)
         self.plugins = allow
-
-    
