@@ -110,7 +110,7 @@ class TestExpander(unittest.TestCase):
         except AssertionError:
             et, ev, tb = sys.exc_info()
             out = inspect_traceback(tb)
-            #print "'%s'" % out.strip()
+            print "'%s'" % out.strip()
             self.assertEqual(out.strip(),
                              "assert {'setup': 1}['setup']\n" 
                              "    print 1, 3\n"
@@ -135,6 +135,6 @@ class TestExpander(unittest.TestCase):
 if __name__ == '__main__':
     #import logging
     #logging.basicConfig()
-    #logging.getLogger('nose.inspector').setLevel(10)
+    #logging.getLogger('').setLevel(10)
     unittest.main()
     
